local L = AceLibrary("AceLocale-2.2"):new("AHDND")

local opts = {
    type='group',
    args = {
         msg = {
            type = 'text',
            name = L["Message"],
            desc = L["Sets the message to be displayed when you are in DND Mode."],
            usage = L["<Your message>"],
            get = "GetMessage",
            set = "SetMessage",
               },
        dndmode = {
            type = 'toggle',
            name = 'Is in DND Mode',
            desc = L["If set to ON, you will go into DND Mode. If set to OFF, you will go into AFK Mode."],
            get = "IsDNDMode",
            set = "ToggleDNDMode",
              },
        instancemode = {
            type = 'toggle',
            name = 'Instance Mode',
            desc = L["If set to ON, you will go automatically into DND/AFK Mode when entering an instance."],
            get = "IsInstanceMode",
            set = "ToggleInstanceMode",
              },
          },
}

AHDND = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceConsole-2.0", "AceDB-2.0")
AHDND:RegisterChatCommand(L['Slash-Commands'], opts)

AHDND:RegisterDB("AHDNDDB", "AHDNDDBPC")
AHDND:RegisterDefaults("profile", {
    message = "I am currently notavailable. Please try again later.",
    dndmode = true,
    instancemode = false,
} )

function AHDND:OnInitialize()
    -- Called when the addon is loaded
    self:Print(L['AHDND loaded.'])
end

function AHDND:OnEnable()
    -- Called when the addon is enabled
    self:Print(L['AHDND enabled. Use /ahdnd to access configuration options.'])
    self:RegisterEvent("AUCTION_HOUSE_SHOW")
    self:RegisterEvent("PLAYER_ENTERING_WORLD")
end

function AHDND:OnDisable()
    -- Called when the addon is disabled
    self:Print(L['AHDND disabled.'])
    self:UnregisterAllEvents()
end

function AHDND:AUCTION_HOUSE_SHOW()
  if not UnitIsDND("player") or not UnitIsAFK("player") then
    self:RegisterEvent("AUCTION_HOUSE_CLOSED")
    UIErrorsFrame:AddMessage(L['AH DND/AFK Mode activated!'], 1.0, 1.0, 0.0, 5.0)
    if self.db.profile.dndmode then
      SendChatMessage(self.db.profile.message, "DND")
    else
      SendChatMessage(self.db.profile.message, "AFK")
    end
  end
end

function AHDND:PLAYER_ENTERING_WORLD()
local posX, posY = GetPlayerMapPosition("player");
  if not UnitIsDND("player") or not UnitIsAFK("player") then
    if self.db.profile.instancemode then
      if (posX == 0) and (posY == 0) then
        UIErrorsFrame:AddMessage(L['Instance DND/AFK Mode activated!'], 1.0, 1.0, 0.0, 5.0)
        if self.db.profile.dndmode then
          SendChatMessage(self.db.profile.message, "DND")
        else
          SendChatMessage(self.db.profile.message, "AFK")
        end
      else
        UIErrorsFrame:AddMessage(L['Instance DND/AFK Mode deactivated!'], 1.0, 1.0, 0.0, 5.0)
        if self.db.profile.dndmode then
          SendChatMessage("", "DND")
        else
          SendChatMessage("", "AFK")
        end
      end
    end
  end
end

function AHDND:AUCTION_HOUSE_CLOSED()
  if UnitIsDND("player") or UnitIsAFK("player") then
  self:UnregisterEvent("AUCTION_HOUSE_CLOSED")
    UIErrorsFrame:AddMessage(L['AH DND/AFK Mode deactivated!'], 0.0, 1.0, 0.0, 5.0)
    if self.db.profile.dndmode then
      SendChatMessage("", "DND")
    else
      SendChatMessage("", "AFK")
    end
  end
end

function AHDND:GetMessage()
    return self.db.profile.message
end

function AHDND:SetMessage(newValue)
    self.db.profile.message = newValue
end

function AHDND:IsDNDMode()
    return self.db.profile.dndmode
end

function AHDND:ToggleDNDMode()
    self.db.profile.dndmode = not self.db.profile.dndmode
end

function AHDND:IsInstanceMode()
    return self.db.profile.instancemode
end

function AHDND:ToggleInstanceMode()
    self.db.profile.instancemode = not self.db.profile.instancemode
end
